@@ -111,10 +111,10 @@ impl<R: Read> LilimReader<R> {
             let pickup = customers.get(&relation.pickup).unwrap();
             let delivery = customers.get(&relation.delivery).unwrap();
 
-            jobs.push(Job::Multi(Multi::bind(Multi::new(
+            jobs.push(Job::Multi(Multi::new_shared(
                 vec![self.create_single_job(pickup), self.create_single_job(delivery)],
                 create_dimens_with_id("mlt", &index.to_string()),
-            ))));
+            )));
         });
 
         Ok(jobs)
@@ -150,7 +150,7 @@ impl<R: Read> LilimReader<R> {
             .buffer
             .split_whitespace()
             .map(|line| line.parse::<usize>().unwrap())
-            .try_collect()
+            .try_collect_tuple()
             .ok_or_else(|| "cannot parse vehicle number or/and capacity".to_string())?;
 
         Ok(VehicleLine { number, capacity, _ignored })
@@ -162,7 +162,7 @@ impl<R: Read> LilimReader<R> {
             .buffer
             .split_whitespace()
             .map(|line| line.parse::<i32>().unwrap())
-            .try_collect()
+            .try_collect_tuple()
             .ok_or_else(|| "cannot read customer line".to_string())?;
         Ok(JobLine {
             id: id as usize,
